import "../stylesheets/QuickActions.css"
import useGrowbrosFetcher from "../utils/useGrowbrosFetcher.ts";
import HeartBrokenIcon from "@mui/icons-material/HeartBroken";
import AgricultureIcon from "@mui/icons-material/Agriculture";
import {FetchResult} from "../utils/FetchResult.ts";
import {useState} from "react";

export type QuickActionButtonProps = {
    type: QuickActionButtonType,
    plantId: number,
    onSuccess?: () => void,
}

export type QuickActionButtonType = "ADD_TO_WISHLIST" | "REMOVE_FROM_WISHLIST" | "ADD_TO_GARDEN" | "REMOVE_FROM_GARDEN"

function QuickActionButton({type, plantId, onSuccess}: QuickActionButtonProps) {
    const [error, setError] = useState();

    const bc = useGrowbrosFetcher();

    async function withOnSuccess<T>(fn: () => Promise<FetchResult<T>>) {
        try {
            const result = await fn();
            if (result.err) {
                return;
            }
        } catch (e) {
            return;
        }
        if (onSuccess) {
            onSuccess();
        } else {
            console.log("Warning: no 'onSuccess' function defined for this component but withOnSuccess was called.");
        }
    }

    switch (type) {
        case "ADD_TO_WISHLIST":
            return <button onClick={() => bc.addToWishlist(plantId)} className={"fa fa-heart quickActionButton"}
                           title={"Add this plant to your wishlist"}/>
        case "ADD_TO_GARDEN":
            return <button onClick={() => bc.addToGarden(plantId)} className={"fa fa-leaf quickActionButton"}
                           title={"Add this plant to your garden"}/>
        case "REMOVE_FROM_WISHLIST":
            return (<button onClick={() => withOnSuccess(() => bc.removeFromWishlist(plantId))}
                            className={"quickActionButton"}
                            title={"Remove this plant from your wishlist"}><HeartBrokenIcon sx={{fontSize: 19}}/>
            </button>)
        case "REMOVE_FROM_GARDEN":
            return (<button onClick={() => withOnSuccess(() => bc.removeFromGarden(plantId))}
                            className={"quickActionButton"}
                            title={"Remove this plant from your garden"}><AgricultureIcon/>
            </button>)
    }
}

export default QuickActionButton;
